
# ----------------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
# http://www.apache.org/licenses/LICENSE-2.0
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
# Code generated by Microsoft (R) AutoRest Code Generator.Changes may cause incorrect behavior and will be lost if the code
# is regenerated.
# ----------------------------------------------------------------------------------

<#
.Synopsis
Create an in-memory object for Configuration.
.Description
Create an in-memory object for Configuration.

.Outputs
Microsoft.Azure.PowerShell.Cmdlets.App.Models.Configuration
.Link
https://learn.microsoft.com/powershell/module/Az.App/new-azcontainerappconfigurationobject
#>
function New-AzContainerAppConfigurationObject {
    [OutputType('Microsoft.Azure.PowerShell.Cmdlets.App.Models.Configuration')]
    [CmdletBinding(PositionalBinding=$false)]
    Param(

        [Parameter(HelpMessage="ActiveRevisionsMode controls how active revisions are handled for the Container app:
        <list><item>Multiple: multiple revisions can be active.</item><item>Single: Only one revision can be active at a time. Revision weights can not be used in this mode. If no value if provided, this is the default.</item></list>.")]
        [Microsoft.Azure.PowerShell.Cmdlets.App.PSArgumentCompleterAttribute("Multiple", "Single")]
        [string]
        $ActiveRevisionsMode,
        [Parameter(HelpMessage="Specifies whether the resource allows credentials.")]
        [bool]
        $CorPolicyAllowCredentials,
        [Parameter(HelpMessage="Specifies the content for the access-control-allow-headers header.")]
        [string[]]
        $CorPolicyAllowedHeader,
        [Parameter(HelpMessage="Specifies the content for the access-control-allow-methods header.")]
        [string[]]
        $CorPolicyAllowedMethod,
        [Parameter(HelpMessage="Specifies the content for the access-control-allow-origins header.")]
        [string[]]
        $CorPolicyAllowedOrigin,
        [Parameter(HelpMessage="Specifies the content for the access-control-expose-headers header .")]
        [string[]]
        $CorPolicyExposeHeader,
        [Parameter(HelpMessage="Specifies the content for the access-control-max-age header.")]
        [int]
        $CorPolicyMaxAge,
        [Parameter(HelpMessage="Dapr application identifier.")]
        [string]
        $DaprAppId,
        [Parameter(HelpMessage="Tells Dapr which port your application is listening on.")]
        [int]
        $DaprAppPort,
        [Parameter(HelpMessage="Tells Dapr which protocol your application is using. Valid options are http and grpc. Default is http.")]
        [Microsoft.Azure.PowerShell.Cmdlets.App.PSArgumentCompleterAttribute("http", "grpc")]
        [string]
        $DaprAppProtocol,
        [Parameter(HelpMessage="Enables API logging for the Dapr sidecar.")]
        [bool]
        $DaprEnableApiLogging,
        [Parameter(HelpMessage="Boolean indicating if the Dapr side car is enabled.")]
        [bool]
        $DaprEnabled,
        [Parameter(HelpMessage="Increasing max size of request body http and grpc servers parameter in MB to handle uploading of big files. Default is 4 MB.")]
        [int]
        $DaprHttpMaxRequestSize,
        [Parameter(HelpMessage="Dapr max size of http header read buffer in KB to handle when sending multi-KB headers. Default is 65KB.")]
        [int]
        $DaprHttpReadBufferSize,
        [Parameter(HelpMessage="Sets the log level for the Dapr sidecar. Allowed values are debug, info, warn, error. Default is info.")]
        [Microsoft.Azure.PowerShell.Cmdlets.App.PSArgumentCompleterAttribute("info", "debug", "warn", "error")]
        [string]
        $DaprLogLevel,
        [Parameter(HelpMessage="Bool indicating if HTTP connections to is allowed. If set to false HTTP connections are automatically redirected to HTTPS connections.")]
        [bool]
        $IngressAllowInsecure,
        [Parameter(HelpMessage="Client certificate mode for mTLS authentication. Ignore indicates server drops client certificate on forwarding. Accept indicates server forwards client certificate but does not require a client certificate. Require indicates server requires a client certificate.")]
        [Microsoft.Azure.PowerShell.Cmdlets.App.PSArgumentCompleterAttribute("ignore", "accept", "require")]
        [string]
        $IngressClientCertificateMode,
        [Parameter(HelpMessage="custom domain bindings for Container Apps' hostnames.")]
        [Microsoft.Azure.PowerShell.Cmdlets.App.Models.ICustomDomain[]]
        $IngressCustomDomain,
        [Parameter(HelpMessage="Exposed Port in containers for TCP traffic from ingress.")]
        [int]
        $IngressExposedPort,
        [Parameter(HelpMessage="Bool indicating if app exposes an external http endpoint.")]
        [bool]
        $IngressExternal,
        [Parameter(HelpMessage="Rules to restrict incoming IP address.")]
        [Microsoft.Azure.PowerShell.Cmdlets.App.Models.IIPSecurityRestrictionRule[]]
        $IngressIPSecurityRestriction,
        [Parameter(HelpMessage="Target Port in containers for traffic from ingress.")]
        [int]
        $IngressTargetPort,
        [Parameter(HelpMessage="Traffic weights for app's revisions.")]
        [Microsoft.Azure.PowerShell.Cmdlets.App.Models.ITrafficWeight[]]
        $IngressTraffic,
        [Parameter(HelpMessage="Ingress transport protocol.")]
        [Microsoft.Azure.PowerShell.Cmdlets.App.PSArgumentCompleterAttribute("auto", "http", "http2", "tcp")]
        [string]
        $IngressTransport,
        [Parameter(HelpMessage="Optional. Max inactive revisions a Container App can have.")]
        [int]
        $MaxInactiveRevision,
        [Parameter(HelpMessage="Collection of private container registry credentials for containers used by the Container app.")]
        [Microsoft.Azure.PowerShell.Cmdlets.App.Models.IRegistryCredentials[]]
        $Registry,
        [Parameter(HelpMessage="Collection of secrets used by a Container app.")]
        [Microsoft.Azure.PowerShell.Cmdlets.App.Models.ISecret[]]
        $Secret,
        [Parameter(HelpMessage="Dev ContainerApp service type.")]
        [string]
        $ServiceType,
        [Parameter(HelpMessage="Sticky Session Affinity.")]
        [Microsoft.Azure.PowerShell.Cmdlets.App.PSArgumentCompleterAttribute("sticky", "none")]
        [string]
        $StickySessionAffinity
    )

    process {
        $Object = [Microsoft.Azure.PowerShell.Cmdlets.App.Models.Configuration]::New()

        if ($PSBoundParameters.ContainsKey('ActiveRevisionsMode')) {
            $Object.ActiveRevisionsMode = $ActiveRevisionsMode
        }
        if ($PSBoundParameters.ContainsKey('CorPolicyAllowCredentials')) {
            $Object.CorPolicyAllowCredentials = $CorPolicyAllowCredentials
        }
        if ($PSBoundParameters.ContainsKey('CorPolicyAllowedHeader')) {
            $Object.CorPolicyAllowedHeader = $CorPolicyAllowedHeader
        }
        if ($PSBoundParameters.ContainsKey('CorPolicyAllowedMethod')) {
            $Object.CorPolicyAllowedMethod = $CorPolicyAllowedMethod
        }
        if ($PSBoundParameters.ContainsKey('CorPolicyAllowedOrigin')) {
            $Object.CorPolicyAllowedOrigin = $CorPolicyAllowedOrigin
        }
        if ($PSBoundParameters.ContainsKey('CorPolicyExposeHeader')) {
            $Object.CorPolicyExposeHeader = $CorPolicyExposeHeader
        }
        if ($PSBoundParameters.ContainsKey('CorPolicyMaxAge')) {
            $Object.CorPolicyMaxAge = $CorPolicyMaxAge
        }
        if ($PSBoundParameters.ContainsKey('DaprAppId')) {
            $Object.DaprAppId = $DaprAppId
        }
        if ($PSBoundParameters.ContainsKey('DaprAppPort')) {
            $Object.DaprAppPort = $DaprAppPort
        }
        if ($PSBoundParameters.ContainsKey('DaprAppProtocol')) {
            $Object.DaprAppProtocol = $DaprAppProtocol
        }
        if ($PSBoundParameters.ContainsKey('DaprEnableApiLogging')) {
            $Object.DaprEnableApiLogging = $DaprEnableApiLogging
        }
        if ($PSBoundParameters.ContainsKey('DaprEnabled')) {
            $Object.DaprEnabled = $DaprEnabled
        }
        if ($PSBoundParameters.ContainsKey('DaprHttpMaxRequestSize')) {
            $Object.DaprHttpMaxRequestSize = $DaprHttpMaxRequestSize
        }
        if ($PSBoundParameters.ContainsKey('DaprHttpReadBufferSize')) {
            $Object.DaprHttpReadBufferSize = $DaprHttpReadBufferSize
        }
        if ($PSBoundParameters.ContainsKey('DaprLogLevel')) {
            $Object.DaprLogLevel = $DaprLogLevel
        }
        if ($PSBoundParameters.ContainsKey('IngressAllowInsecure')) {
            $Object.IngressAllowInsecure = $IngressAllowInsecure
        }
        if ($PSBoundParameters.ContainsKey('IngressClientCertificateMode')) {
            $Object.IngressClientCertificateMode = $IngressClientCertificateMode
        }
        if ($PSBoundParameters.ContainsKey('IngressCustomDomain')) {
            $Object.IngressCustomDomain = $IngressCustomDomain
        }
        if ($PSBoundParameters.ContainsKey('IngressExposedPort')) {
            $Object.IngressExposedPort = $IngressExposedPort
        }
        if ($PSBoundParameters.ContainsKey('IngressExternal')) {
            $Object.IngressExternal = $IngressExternal
        }
        if ($PSBoundParameters.ContainsKey('IngressIPSecurityRestriction')) {
            $Object.IngressIPSecurityRestriction = $IngressIPSecurityRestriction
        }
        if ($PSBoundParameters.ContainsKey('IngressTargetPort')) {
            $Object.IngressTargetPort = $IngressTargetPort
        }
        if ($PSBoundParameters.ContainsKey('IngressTraffic')) {
            $Object.IngressTraffic = $IngressTraffic
        }
        if ($PSBoundParameters.ContainsKey('IngressTransport')) {
            $Object.IngressTransport = $IngressTransport
        }
        if ($PSBoundParameters.ContainsKey('MaxInactiveRevision')) {
            $Object.MaxInactiveRevision = $MaxInactiveRevision
        }
        if ($PSBoundParameters.ContainsKey('Registry')) {
            $Object.Registry = $Registry
        }
        if ($PSBoundParameters.ContainsKey('Secret')) {
            $Object.Secret = $Secret
        }
        if ($PSBoundParameters.ContainsKey('ServiceType')) {
            $Object.ServiceType = $ServiceType
        }
        if ($PSBoundParameters.ContainsKey('StickySessionAffinity')) {
            $Object.StickySessionAffinity = $StickySessionAffinity
        }
        return $Object
    }
}


# SIG # Begin signature block
# MIIoLQYJKoZIhvcNAQcCoIIoHjCCKBoCAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCDQp4l9WjFvt601
# 9BRQQCWAqLuVPySzOS/o3eW19H3pOKCCDXYwggX0MIID3KADAgECAhMzAAADTrU8
# esGEb+srAAAAAANOMA0GCSqGSIb3DQEBCwUAMH4xCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25p
# bmcgUENBIDIwMTEwHhcNMjMwMzE2MTg0MzI5WhcNMjQwMzE0MTg0MzI5WjB0MQsw
# CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9u
# ZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMR4wHAYDVQQDExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB
# AQDdCKiNI6IBFWuvJUmf6WdOJqZmIwYs5G7AJD5UbcL6tsC+EBPDbr36pFGo1bsU
# p53nRyFYnncoMg8FK0d8jLlw0lgexDDr7gicf2zOBFWqfv/nSLwzJFNP5W03DF/1
# 1oZ12rSFqGlm+O46cRjTDFBpMRCZZGddZlRBjivby0eI1VgTD1TvAdfBYQe82fhm
# WQkYR/lWmAK+vW/1+bO7jHaxXTNCxLIBW07F8PBjUcwFxxyfbe2mHB4h1L4U0Ofa
# +HX/aREQ7SqYZz59sXM2ySOfvYyIjnqSO80NGBaz5DvzIG88J0+BNhOu2jl6Dfcq
# jYQs1H/PMSQIK6E7lXDXSpXzAgMBAAGjggFzMIIBbzAfBgNVHSUEGDAWBgorBgEE
# AYI3TAgBBggrBgEFBQcDAzAdBgNVHQ4EFgQUnMc7Zn/ukKBsBiWkwdNfsN5pdwAw
# RQYDVR0RBD4wPKQ6MDgxHjAcBgNVBAsTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEW
# MBQGA1UEBRMNMjMwMDEyKzUwMDUxNjAfBgNVHSMEGDAWgBRIbmTlUAXTgqoXNzci
# tW2oynUClTBUBgNVHR8ETTBLMEmgR6BFhkNodHRwOi8vd3d3Lm1pY3Jvc29mdC5j
# b20vcGtpb3BzL2NybC9NaWNDb2RTaWdQQ0EyMDExXzIwMTEtMDctMDguY3JsMGEG
# CCsGAQUFBwEBBFUwUzBRBggrBgEFBQcwAoZFaHR0cDovL3d3dy5taWNyb3NvZnQu
# Y29tL3BraW9wcy9jZXJ0cy9NaWNDb2RTaWdQQ0EyMDExXzIwMTEtMDctMDguY3J0
# MAwGA1UdEwEB/wQCMAAwDQYJKoZIhvcNAQELBQADggIBAD21v9pHoLdBSNlFAjmk
# mx4XxOZAPsVxxXbDyQv1+kGDe9XpgBnT1lXnx7JDpFMKBwAyIwdInmvhK9pGBa31
# TyeL3p7R2s0L8SABPPRJHAEk4NHpBXxHjm4TKjezAbSqqbgsy10Y7KApy+9UrKa2
# kGmsuASsk95PVm5vem7OmTs42vm0BJUU+JPQLg8Y/sdj3TtSfLYYZAaJwTAIgi7d
# hzn5hatLo7Dhz+4T+MrFd+6LUa2U3zr97QwzDthx+RP9/RZnur4inzSQsG5DCVIM
# pA1l2NWEA3KAca0tI2l6hQNYsaKL1kefdfHCrPxEry8onJjyGGv9YKoLv6AOO7Oh
# JEmbQlz/xksYG2N/JSOJ+QqYpGTEuYFYVWain7He6jgb41JbpOGKDdE/b+V2q/gX
# UgFe2gdwTpCDsvh8SMRoq1/BNXcr7iTAU38Vgr83iVtPYmFhZOVM0ULp/kKTVoir
# IpP2KCxT4OekOctt8grYnhJ16QMjmMv5o53hjNFXOxigkQWYzUO+6w50g0FAeFa8
# 5ugCCB6lXEk21FFB1FdIHpjSQf+LP/W2OV/HfhC3uTPgKbRtXo83TZYEudooyZ/A
# Vu08sibZ3MkGOJORLERNwKm2G7oqdOv4Qj8Z0JrGgMzj46NFKAxkLSpE5oHQYP1H
# tPx1lPfD7iNSbJsP6LiUHXH1MIIHejCCBWKgAwIBAgIKYQ6Q0gAAAAAAAzANBgkq
# hkiG9w0BAQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24x
# EDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
# bjEyMDAGA1UEAxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9yaXR5
# IDIwMTEwHhcNMTEwNzA4MjA1OTA5WhcNMjYwNzA4MjEwOTA5WjB+MQswCQYDVQQG
# EwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwG
# A1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQg
# Q29kZSBTaWduaW5nIFBDQSAyMDExMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIIC
# CgKCAgEAq/D6chAcLq3YbqqCEE00uvK2WCGfQhsqa+laUKq4BjgaBEm6f8MMHt03
# a8YS2AvwOMKZBrDIOdUBFDFC04kNeWSHfpRgJGyvnkmc6Whe0t+bU7IKLMOv2akr
# rnoJr9eWWcpgGgXpZnboMlImEi/nqwhQz7NEt13YxC4Ddato88tt8zpcoRb0Rrrg
# OGSsbmQ1eKagYw8t00CT+OPeBw3VXHmlSSnnDb6gE3e+lD3v++MrWhAfTVYoonpy
# 4BI6t0le2O3tQ5GD2Xuye4Yb2T6xjF3oiU+EGvKhL1nkkDstrjNYxbc+/jLTswM9
# sbKvkjh+0p2ALPVOVpEhNSXDOW5kf1O6nA+tGSOEy/S6A4aN91/w0FK/jJSHvMAh
# dCVfGCi2zCcoOCWYOUo2z3yxkq4cI6epZuxhH2rhKEmdX4jiJV3TIUs+UsS1Vz8k
# A/DRelsv1SPjcF0PUUZ3s/gA4bysAoJf28AVs70b1FVL5zmhD+kjSbwYuER8ReTB
# w3J64HLnJN+/RpnF78IcV9uDjexNSTCnq47f7Fufr/zdsGbiwZeBe+3W7UvnSSmn
# Eyimp31ngOaKYnhfsi+E11ecXL93KCjx7W3DKI8sj0A3T8HhhUSJxAlMxdSlQy90
# lfdu+HggWCwTXWCVmj5PM4TasIgX3p5O9JawvEagbJjS4NaIjAsCAwEAAaOCAe0w
# ggHpMBAGCSsGAQQBgjcVAQQDAgEAMB0GA1UdDgQWBBRIbmTlUAXTgqoXNzcitW2o
# ynUClTAZBgkrBgEEAYI3FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYwDwYD
# VR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBRyLToCMZBDuRQFTuHqp8cx0SOJNDBa
# BgNVHR8EUzBRME+gTaBLhklodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2Ny
# bC9wcm9kdWN0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFfMDNfMjIuY3JsMF4GCCsG
# AQUFBwEBBFIwUDBOBggrBgEFBQcwAoZCaHR0cDovL3d3dy5taWNyb3NvZnQuY29t
# L3BraS9jZXJ0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFfMDNfMjIuY3J0MIGfBgNV
# HSAEgZcwgZQwgZEGCSsGAQQBgjcuAzCBgzA/BggrBgEFBQcCARYzaHR0cDovL3d3
# dy5taWNyb3NvZnQuY29tL3BraW9wcy9kb2NzL3ByaW1hcnljcHMuaHRtMEAGCCsG
# AQUFBwICMDQeMiAdAEwAZQBnAGEAbABfAHAAbwBsAGkAYwB5AF8AcwB0AGEAdABl
# AG0AZQBuAHQALiAdMA0GCSqGSIb3DQEBCwUAA4ICAQBn8oalmOBUeRou09h0ZyKb
# C5YR4WOSmUKWfdJ5DJDBZV8uLD74w3LRbYP+vj/oCso7v0epo/Np22O/IjWll11l
# hJB9i0ZQVdgMknzSGksc8zxCi1LQsP1r4z4HLimb5j0bpdS1HXeUOeLpZMlEPXh6
# I/MTfaaQdION9MsmAkYqwooQu6SpBQyb7Wj6aC6VoCo/KmtYSWMfCWluWpiW5IP0
# wI/zRive/DvQvTXvbiWu5a8n7dDd8w6vmSiXmE0OPQvyCInWH8MyGOLwxS3OW560
# STkKxgrCxq2u5bLZ2xWIUUVYODJxJxp/sfQn+N4sOiBpmLJZiWhub6e3dMNABQam
# ASooPoI/E01mC8CzTfXhj38cbxV9Rad25UAqZaPDXVJihsMdYzaXht/a8/jyFqGa
# J+HNpZfQ7l1jQeNbB5yHPgZ3BtEGsXUfFL5hYbXw3MYbBL7fQccOKO7eZS/sl/ah
# XJbYANahRr1Z85elCUtIEJmAH9AAKcWxm6U/RXceNcbSoqKfenoi+kiVH6v7RyOA
# 9Z74v2u3S5fi63V4GuzqN5l5GEv/1rMjaHXmr/r8i+sLgOppO6/8MO0ETI7f33Vt
# Y5E90Z1WTk+/gFcioXgRMiF670EKsT/7qMykXcGhiJtXcVZOSEXAQsmbdlsKgEhr
# /Xmfwb1tbWrJUnMTDXpQzTGCGg0wghoJAgEBMIGVMH4xCzAJBgNVBAYTAlVTMRMw
# EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVN
# aWNyb3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNp
# Z25pbmcgUENBIDIwMTECEzMAAANOtTx6wYRv6ysAAAAAA04wDQYJYIZIAWUDBAIB
# BQCgga4wGQYJKoZIhvcNAQkDMQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEO
# MAwGCisGAQQBgjcCARUwLwYJKoZIhvcNAQkEMSIEIARJPnB2tnKEeny0V1Njzywt
# bt6j5jNJYPWJKdBMAnkCMEIGCisGAQQBgjcCAQwxNDAyoBSAEgBNAGkAYwByAG8A
# cwBvAGYAdKEagBhodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20wDQYJKoZIhvcNAQEB
# BQAEggEA0FDri4vyXIXmT4b240ejK0Xho2tcNad1i93qOjdbxxcHxPFfsa/k/puP
# M1lXB57027U6sSkmo8DfVIDw2wvD07P4dSIU7WQiSPY0OgyETZT78m9Ze+eaUaUF
# GQBPFJc1xXtehaxnVwM9VRq7MoM9iKmwTQ43JnwhFUPcw42q1Y8eHavOR3zlQmX2
# 5ZWgBFrJtkrnJLp1r3XcgAQKrhm6msMaBkj+G+m+K22bjHmZmIxXxd0zEA82zk1k
# rWXZDHmLQrfoEgZVGn4ARvkzvGUn0S1eE13c0V3uRQ1v7fR11oDTTMfpaXWsgmYY
# 6GhNqjHgzbXE7/4Ja/HV7ZSHQB+ZlKGCF5cwgheTBgorBgEEAYI3AwMBMYIXgzCC
# F38GCSqGSIb3DQEHAqCCF3AwghdsAgEDMQ8wDQYJYIZIAWUDBAIBBQAwggFSBgsq
# hkiG9w0BCRABBKCCAUEEggE9MIIBOQIBAQYKKwYBBAGEWQoDATAxMA0GCWCGSAFl
# AwQCAQUABCC/zuNhWtC8YhnzJ1s7SYf5P7Im7fcbGhzZoZ40pY4ErQIGZSiV3LXz
# GBMyMDIzMTExMDA0MjUzMC45MDVaMASAAgH0oIHRpIHOMIHLMQswCQYDVQQGEwJV
# UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UE
# ChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSUwIwYDVQQLExxNaWNyb3NvZnQgQW1l
# cmljYSBPcGVyYXRpb25zMScwJQYDVQQLEx5uU2hpZWxkIFRTUyBFU046ODkwMC0w
# NUUwLUQ5NDcxJTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1lLVN0YW1wIFNlcnZpY2Wg
# ghHtMIIHIDCCBQigAwIBAgITMwAAAdMdMpoXO0AwcwABAAAB0zANBgkqhkiG9w0B
# AQsFADB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UE
# BxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYD
# VQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDAeFw0yMzA1MjUxOTEy
# MjRaFw0yNDAyMDExOTEyMjRaMIHLMQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2Fz
# aGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENv
# cnBvcmF0aW9uMSUwIwYDVQQLExxNaWNyb3NvZnQgQW1lcmljYSBPcGVyYXRpb25z
# MScwJQYDVQQLEx5uU2hpZWxkIFRTUyBFU046ODkwMC0wNUUwLUQ5NDcxJTAjBgNV
# BAMTHE1pY3Jvc29mdCBUaW1lLVN0YW1wIFNlcnZpY2UwggIiMA0GCSqGSIb3DQEB
# AQUAA4ICDwAwggIKAoICAQC0jquTN4g1xbhXCc8MV+dOu8Uqc3KbbaWti5vdsAWM
# 1D4fVSi+4NWgGtP/BVRYrVj2oVnnMy0eazidQOJ4uUscBMbPHaMxaNpgbRG9FEQR
# FncAUptWnI+VPl53PD6MPL0yz8cHC2ZD3weF4w+uMDAGnL36Bkm0srONXvnM9eNv
# nG5djopEqiHodWSauRye4uftBR2sTwGHVmxKu0GS4fO87NgbJ4VGzICRyZXw9+Rv
# vXMG/jhM11H8AWKzKpn0oMGm1MSMeNvLUWb31HSZekx/NBEtXvmdo75OV030NHgI
# XihxYEeSgUIxfbI5OmgMq/VDCQp2r/fy/5NVa3KjCQoNqmmEM6orAJ2XKjYhEJzo
# p4nWCcJ970U6rXpBPK4XGNKBFhhLa74TM/ysTFIrEXOJG1fUuXfcdWb0Ex0FAeTT
# r6gmmCqreJNejNHffG/VEeF7LNvUquYFRndiCUhgy624rW6ptcnQTiRfE0QL/gLF
# 41kA2vZMYzcc16EiYXQQBaF3XAtMduh1dpXqTPPQEO3Ms5/5B/KtjhSspMcPUvRv
# b35IWN+q+L+zEwiphmnCGFTuyOMqc5QE0ruGN3Mx0Vv6x/hcOmaXxrHQGpNKI5Pn
# 79Yk89AclqU2mXHz1ZHWp+KBc3D6VP7L32JlwxhJx3asa085xv0XPD58MRW1WaGv
# aQIDAQABo4IBSTCCAUUwHQYDVR0OBBYEFNLHIIa4FAD494z35hvzCmm0415iMB8G
# A1UdIwQYMBaAFJ+nFV0AXmJdg/Tl0mWnG1M1GelyMF8GA1UdHwRYMFYwVKBSoFCG
# Tmh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMvY3JsL01pY3Jvc29mdCUy
# MFRpbWUtU3RhbXAlMjBQQ0ElMjAyMDEwKDEpLmNybDBsBggrBgEFBQcBAQRgMF4w
# XAYIKwYBBQUHMAKGUGh0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMvY2Vy
# dHMvTWljcm9zb2Z0JTIwVGltZS1TdGFtcCUyMFBDQSUyMDIwMTAoMSkuY3J0MAwG
# A1UdEwEB/wQCMAAwFgYDVR0lAQH/BAwwCgYIKwYBBQUHAwgwDgYDVR0PAQH/BAQD
# AgeAMA0GCSqGSIb3DQEBCwUAA4ICAQBAYlhYoUQ+4aaQ54MFNfE6Ey8v4rWv+LtD
# RSjMM2X9g4uanA9cU7VitdpIPV/zE6v4AEhe/Vng2UAR5qj2SV3sz+fDqN6VLWUZ
# sKR0QR2JYXKnFPRVj16ezZyP7zd5H8IsvscEconeX+aRHF0xGGM4tDLrS84vj6Rm
# 0bgoWLXWnMTZ5kP4ownGmm0LsmInuu0GKrDZnkeTVmfk8gTTy8d1y3P2IYc2UI4i
# JYXCuSaKCuFeO0wqyscpvhGQSno1XAFK3oaybuD1mSoQxT9q77+LAGGQbiSoGlgT
# jQQayYsQaPcG1Q4QNwONGqkASCZTbzJlnmkHgkWlKSLTulOailWIY4hS1EZ+w+sX
# 0BJ9LcM142h51OlXLMoPLpzHAb6x22ipaAJ5Kf3uyFaOKWw4hnu0zWs+PKPd192n
# deK2ogWfaFdfnEvkWDDH2doL+ZA5QBd8Xngs/md3Brnll2BkZ/giZE/fKyolriR3
# aTAWCxFCXKIl/Clu2bbnj9qfVYLpAVQEcPaCfTAf7OZBlXmluETvq1Y/SNhxC6MJ
# 1QLCnkXSI//iXYpmRKT783QKRgmo/4ztj3uL9Z7xbbGxISg+P0HTRX15y4TReBbO
# 2RFNyCj88gOORk+swT1kaKXUfGB4zjg5XulxSby3uLNxQebE6TE3cAK0+fnY5UpH
# aEdlw4e7ijCCB3EwggVZoAMCAQICEzMAAAAVxedrngKbSZkAAAAAABUwDQYJKoZI
# hvcNAQELBQAwgYgxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAw
# DgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24x
# MjAwBgNVBAMTKU1pY3Jvc29mdCBSb290IENlcnRpZmljYXRlIEF1dGhvcml0eSAy
# MDEwMB4XDTIxMDkzMDE4MjIyNVoXDTMwMDkzMDE4MzIyNVowfDELMAkGA1UEBhMC
# VVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNV
# BAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRp
# bWUtU3RhbXAgUENBIDIwMTAwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoIC
# AQDk4aZM57RyIQt5osvXJHm9DtWC0/3unAcH0qlsTnXIyjVX9gF/bErg4r25Phdg
# M/9cT8dm95VTcVrifkpa/rg2Z4VGIwy1jRPPdzLAEBjoYH1qUoNEt6aORmsHFPPF
# dvWGUNzBRMhxXFExN6AKOG6N7dcP2CZTfDlhAnrEqv1yaa8dq6z2Nr41JmTamDu6
# GnszrYBbfowQHJ1S/rboYiXcag/PXfT+jlPP1uyFVk3v3byNpOORj7I5LFGc6XBp
# Dco2LXCOMcg1KL3jtIckw+DJj361VI/c+gVVmG1oO5pGve2krnopN6zL64NF50Zu
# yjLVwIYwXE8s4mKyzbnijYjklqwBSru+cakXW2dg3viSkR4dPf0gz3N9QZpGdc3E
# XzTdEonW/aUgfX782Z5F37ZyL9t9X4C626p+Nuw2TPYrbqgSUei/BQOj0XOmTTd0
# lBw0gg/wEPK3Rxjtp+iZfD9M269ewvPV2HM9Q07BMzlMjgK8QmguEOqEUUbi0b1q
# GFphAXPKZ6Je1yh2AuIzGHLXpyDwwvoSCtdjbwzJNmSLW6CmgyFdXzB0kZSU2LlQ
# +QuJYfM2BjUYhEfb3BvR/bLUHMVr9lxSUV0S2yW6r1AFemzFER1y7435UsSFF5PA
# PBXbGjfHCBUYP3irRbb1Hode2o+eFnJpxq57t7c+auIurQIDAQABo4IB3TCCAdkw
# EgYJKwYBBAGCNxUBBAUCAwEAATAjBgkrBgEEAYI3FQIEFgQUKqdS/mTEmr6CkTxG
# NSnPEP8vBO4wHQYDVR0OBBYEFJ+nFV0AXmJdg/Tl0mWnG1M1GelyMFwGA1UdIARV
# MFMwUQYMKwYBBAGCN0yDfQEBMEEwPwYIKwYBBQUHAgEWM2h0dHA6Ly93d3cubWlj
# cm9zb2Z0LmNvbS9wa2lvcHMvRG9jcy9SZXBvc2l0b3J5Lmh0bTATBgNVHSUEDDAK
# BggrBgEFBQcDCDAZBgkrBgEEAYI3FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMC
# AYYwDwYDVR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBTV9lbLj+iiXGJo0T2UkFvX
# zpoYxDBWBgNVHR8ETzBNMEugSaBHhkVodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20v
# cGtpL2NybC9wcm9kdWN0cy9NaWNSb29DZXJBdXRfMjAxMC0wNi0yMy5jcmwwWgYI
# KwYBBQUHAQEETjBMMEoGCCsGAQUFBzAChj5odHRwOi8vd3d3Lm1pY3Jvc29mdC5j
# b20vcGtpL2NlcnRzL01pY1Jvb0NlckF1dF8yMDEwLTA2LTIzLmNydDANBgkqhkiG
# 9w0BAQsFAAOCAgEAnVV9/Cqt4SwfZwExJFvhnnJL/Klv6lwUtj5OR2R4sQaTlz0x
# M7U518JxNj/aZGx80HU5bbsPMeTCj/ts0aGUGCLu6WZnOlNN3Zi6th542DYunKmC
# VgADsAW+iehp4LoJ7nvfam++Kctu2D9IdQHZGN5tggz1bSNU5HhTdSRXud2f8449
# xvNo32X2pFaq95W2KFUn0CS9QKC/GbYSEhFdPSfgQJY4rPf5KYnDvBewVIVCs/wM
# nosZiefwC2qBwoEZQhlSdYo2wh3DYXMuLGt7bj8sCXgU6ZGyqVvfSaN0DLzskYDS
# PeZKPmY7T7uG+jIa2Zb0j/aRAfbOxnT99kxybxCrdTDFNLB62FD+CljdQDzHVG2d
# Y3RILLFORy3BFARxv2T5JL5zbcqOCb2zAVdJVGTZc9d/HltEAY5aGZFrDZ+kKNxn
# GSgkujhLmm77IVRrakURR6nxt67I6IleT53S0Ex2tVdUCbFpAUR+fKFhbHP+Crvs
# QWY9af3LwUFJfn6Tvsv4O+S3Fb+0zj6lMVGEvL8CwYKiexcdFYmNcP7ntdAoGokL
# jzbaukz5m/8K6TT4JDVnK+ANuOaMmdbhIurwJ0I9JZTmdHRbatGePu1+oDEzfbzL
# 6Xu/OHBE0ZDxyKs6ijoIYn/ZcGNTTY3ugm2lBRDBcQZqELQdVTNYs6FwZvKhggNQ
# MIICOAIBATCB+aGB0aSBzjCByzELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
# bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
# b3JhdGlvbjElMCMGA1UECxMcTWljcm9zb2Z0IEFtZXJpY2EgT3BlcmF0aW9uczEn
# MCUGA1UECxMeblNoaWVsZCBUU1MgRVNOOjg5MDAtMDVFMC1EOTQ3MSUwIwYDVQQD
# ExxNaWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNloiMKAQEwBwYFKw4DAhoDFQBS
# x23cMcNB1IQws/LYkRXa7I5JsKCBgzCBgKR+MHwxCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1w
# IFBDQSAyMDEwMA0GCSqGSIb3DQEBCwUAAgUA6Pf9VjAiGA8yMDIzMTExMDAwNTIz
# OFoYDzIwMjMxMTExMDA1MjM4WjB3MD0GCisGAQQBhFkKBAExLzAtMAoCBQDo9/1W
# AgEAMAoCAQACAhKvAgH/MAcCAQACAhNBMAoCBQDo+U7WAgEAMDYGCisGAQQBhFkK
# BAIxKDAmMAwGCisGAQQBhFkKAwKgCjAIAgEAAgMHoSChCjAIAgEAAgMBhqAwDQYJ
# KoZIhvcNAQELBQADggEBAGQJRdt9cU74K40bFcaPS85AyJ/bWJLsxcjP6BDm5x/5
# JA2HLf/Fgxk7JANdGfjlvQkgDFUCuLkKu01/eaNum+0FlvoVL6/XeZ5KjeisNkOG
# SfomnJYjI1mckknDru8K9oyKQxTalgQnTEbEyCMrT/8mJq5IFunaa/4OVGv5Vb7g
# ddeYK2akckzFO+iXZ55PJ8Xu13rNXRlb3K/BaZBrfnCQSeFIqT/t3wmPde248Ybn
# SMTjpr1LEZPafiHpyOaKlG5DUJFrM8CE82GStRTpwJ8R2WcxX3MS8s8p1jdGvR+r
# H+Ojk8jcVzTSQOnC1P3lK9zd9+4KIYGACuBHbD/+BcoxggQNMIIECQIBATCBkzB8
# MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVk
# bW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1N
# aWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMAITMwAAAdMdMpoXO0AwcwABAAAB
# 0zANBglghkgBZQMEAgEFAKCCAUowGgYJKoZIhvcNAQkDMQ0GCyqGSIb3DQEJEAEE
# MC8GCSqGSIb3DQEJBDEiBCDa49I473VNtuH3Rz4LvVnZPHsA1pvbHfMGLkronmlb
# ozCB+gYLKoZIhvcNAQkQAi8xgeowgecwgeQwgb0EIJJm9OrE4O5PWA1KaFaztr9u
# P96rQgEn+tgGtY3xOqr1MIGYMIGApH4wfDELMAkGA1UEBhMCVVMxEzARBgNVBAgT
# Cldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29m
# dCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENB
# IDIwMTACEzMAAAHTHTKaFztAMHMAAQAAAdMwIgQgYqQgWuDcXOiPpwhZn2SZwzmv
# Kgbhi5yknvNpZb16FRMwDQYJKoZIhvcNAQELBQAEggIAJqewpn4MCxOtwsN3UHdo
# Q6pSjxINScaQZnkqG7BFO251FMWKjejqxgjgqMsXB8KMBNnZNH2gDwQS/meMseLg
# Qm9Xkwbap80HxvckIFUwNHsNU6zzKLEVIxUSfSnZk99Jf4JBEBmkR/jKYLWwyl8P
# Pbl2A3sr93U5oImLa/RlD8ua3c6tDXO51I6O+OJUHWgzOj/dVE8Qc2J4ggOdGxLl
# PRHmqC13r3u3mVBLDA6pw/UeykVRyPywPtUYT370sPkcq7dspTtpL4bjZ0fSIox1
# 4AEOs7E4oW26upoHZ0U2w5FqaMhpaxGoe6DMBWGlIlSO5DJyqi8jIifvyc5oNM/h
# jH1gFWUQXZ5BQiAhssY0symnrn9qZHH8vKlU1ELBTmVq/QmETzn5u2GkO6id7ZuG
# Nt8yosgHFFwiJlLYl1R38duRixeuxPaU2HMtt4QZSu3C/oktWKbH6FRZh9nnZCWB
# 4U5y3TUYoBaWJvXKb3CGmVlFU2EdbCWQxWeDnUhTtN6OKncf9Jzcl8xktHZ1cEXH
# IPuExrSj/o/rEnsUN1RJ1+pTd8SlxTTZ/tuPZceGEekmLYK6V2ecqZZCOUBRMbPL
# PTLCtn4RzM+fb+wXLUnIE6rO3Qu8vQoUSTrjlXfoTXdk8qpul0int6jhAL7t6P6G
# 9/xeuOqo5tUtzfowVkolSwg=
# SIG # End signature block
