#
# Script module for module 'Az.Sql' that is executed when 'Az.Sql' is imported in a PowerShell session.
#
# Generated by: Microsoft Corporation
#
# Generated on: 12/27/2023 05:39:29
#

$PSDefaultParameterValues.Clear()
Set-StrictMode -Version Latest

function Test-DotNet
{
    try
    {
        if ((Get-PSDrive 'HKLM' -ErrorAction Ignore) -and (-not (Get-ChildItem 'HKLM:\SOFTWARE\Microsoft\NET Framework Setup\NDP\v4\Full\' -ErrorAction Stop | Get-ItemPropertyValue -ErrorAction Stop -Name Release | Where-Object { $_ -ge 461808 })))
        {
            throw ".NET Framework versions lower than 4.7.2 are not supported in Az. Please upgrade to .NET Framework 4.7.2 or higher."
        }
    }
    catch [System.Management.Automation.DriveNotFoundException]
    {
        Write-Verbose ".NET Framework version check failed."
    }
}

function Preload-Assembly {
    param (
        [string]
        $AssemblyDirectory
    )
    if($PSEdition -eq 'Desktop' -and (Test-Path $AssemblyDirectory -ErrorAction Ignore))
    {
        try
        {
            Get-ChildItem -ErrorAction Stop -Path $AssemblyDirectory -Filter "*.dll" | ForEach-Object {
                try
                {
                    Add-Type -Path $_.FullName -ErrorAction Ignore | Out-Null
                }
                catch {
                    Write-Verbose $_
                }
            }
        }
        catch {}
    }
}

if ($true -and ($PSEdition -eq 'Desktop'))
{
    if ($PSVersionTable.PSVersion -lt [Version]'5.1')
    {
        throw "PowerShell versions lower than 5.1 are not supported in Az. Please upgrade to PowerShell 5.1 or higher."
    }

    Test-DotNet
}

if ($true -and ($PSEdition -eq 'Core'))
{
    if ($PSVersionTable.PSVersion -lt [Version]'6.2.4')
    {
        throw "Current Az version doesn't support PowerShell Core versions lower than 6.2.4. Please upgrade to PowerShell Core 6.2.4 or higher."
    }
}

if (Test-Path -Path "$PSScriptRoot\StartupScripts" -ErrorAction Ignore)
{
    Get-ChildItem "$PSScriptRoot\StartupScripts" -ErrorAction Stop | ForEach-Object {
        . $_.FullName
    }
}

# [windows powershell] preload assemblies


# [windows powershell] preload module alc assemblies
$preloadPath = (Join-Path $PSScriptRoot -ChildPath "ModuleAlcAssemblies")
Preload-Assembly -AssemblyDirectory $preloadPath

if (Get-Module AzureRM.profile -ErrorAction Ignore)
{
    Write-Warning ("AzureRM.Profile already loaded. Az and AzureRM modules cannot be imported in the same session or used in the same script or runbook. If you are running PowerShell in an environment you control you can use the 'Uninstall-AzureRm' cmdlet to remove all AzureRm modules from your machine. " +
        "If you are running in Azure Automation, take care that none of your runbooks import both Az and AzureRM modules. More information can be found here: https://aka.ms/azps-migration-guide.")
    throw ("AzureRM.Profile already loaded. Az and AzureRM modules cannot be imported in the same session or used in the same script or runbook. If you are running PowerShell in an environment you control you can use the 'Uninstall-AzureRm' cmdlet to remove all AzureRm modules from your machine. " +
        "If you are running in Azure Automation, take care that none of your runbooks import both Az and AzureRM modules. More information can be found here: https://aka.ms/azps-migration-guide.")
}

$module = Get-Module Az.Accounts 
        if ($module -ne $null -and $module.Version -lt [System.Version]"2.15.0") 
{ 
    Write-Error "This module requires Az.Accounts version 2.15.0. An earlier version of Az.Accounts is imported in the current PowerShell session. Please open a new session before importing this module. This error could indicate that multiple incompatible versions of the Azure PowerShell cmdlets are installed on your system. Please see https://aka.ms/azps-version-error for troubleshooting information." -ErrorAction Stop 
} 
elseif ($module -eq $null) 
{ 
    Import-Module Az.Accounts -MinimumVersion 2.15.0 -Scope Global 
}
Import-Module (Join-Path -Path $PSScriptRoot -ChildPath Microsoft.Azure.PowerShell.Cmdlets.Sql.dll)


if (Test-Path -Path "$PSScriptRoot\PostImportScripts" -ErrorAction Ignore)
{
    Get-ChildItem "$PSScriptRoot\PostImportScripts" -ErrorAction Stop | ForEach-Object {
        . $_.FullName
    }
}

$FilteredCommands = @('Clear-AzSqlDatabaseVulnerabilityAssessmentSetting:ResourceGroupName','Get-AzSqlDatabaseVulnerabilityAssessmentSetting:ResourceGroupName','Update-AzSqlDatabaseVulnerabilityAssessmentSetting:ResourceGroupName','Clear-AzSqlInstanceDatabaseVulnerabilityAssessmentSetting:ResourceGroupName','Get-AzSqlInstanceDatabaseVulnerabilityAssessmentSetting:ResourceGroupName','Update-AzSqlInstanceDatabaseVulnerabilityAssessmentSetting:ResourceGroupName','Convert-AzSqlDatabaseVulnerabilityAssessmentScan:ResourceGroupName','Get-AzSqlDatabaseVulnerabilityAssessmentScanRecord:ResourceGroupName','Start-AzSqlDatabaseVulnerabilityAssessmentScan:ResourceGroupName','Convert-AzSqlInstanceDatabaseVulnerabilityAssessmentScan:ResourceGroupName','Get-AzSqlInstanceDatabaseVulnerabilityAssessmentScanRecord:ResourceGroupName','Start-AzSqlInstanceDatabaseVulnerabilityAssessmentScan:ResourceGroupName','Clear-AzSqlDatabaseVulnerabilityAssessmentRuleBaseline:ResourceGroupName','Get-AzSqlDatabaseVulnerabilityAssessmentRuleBaseline:ResourceGroupName','Set-AzSqlDatabaseVulnerabilityAssessmentRuleBaseline:ResourceGroupName','Clear-AzSqlInstanceDatabaseVulnerabilityAssessmentRuleBaseline:ResourceGroupName','Get-AzSqlInstanceDatabaseVulnerabilityAssessmentRuleBaseline:ResourceGroupName','Set-AzSqlInstanceDatabaseVulnerabilityAssessmentRuleBaseline:ResourceGroupName','Get-AzSqlServerVirtualNetworkRule:ResourceGroupName','New-AzSqlServerVirtualNetworkRule:ResourceGroupName','Remove-AzSqlServerVirtualNetworkRule:ResourceGroupName','Set-AzSqlServerVirtualNetworkRule:ResourceGroupName','Get-AzSqlDatabaseTransparentDataEncryption:ResourceGroupName','Get-AzSqlServerTransparentDataEncryptionProtector:ResourceGroupName','Invoke-AzSqlServerTransparentDataEncryptionProtectorRevalidation:ResourceGroupName','Set-AzSqlDatabaseTransparentDataEncryption:ResourceGroupName','Set-AzSqlServerTransparentDataEncryptionProtector:ResourceGroupName','Get-AzSqlDatabaseUpgradeHint:ResourceGroupName','Get-AzSqlServerUpgradeHint:ResourceGroupName','New-AzSqlServer:ResourceGroupName','Remove-AzSqlServer:ResourceGroupName','Set-AzSqlServer:ResourceGroupName','New-AzSqlServerTrustGroup:ResourceGroupName','Remove-AzSqlServerTrustGroup:ResourceGroupName','Add-AzSqlServerKeyVaultKey:ResourceGroupName','Get-AzSqlServerKeyVaultKey:ResourceGroupName','Remove-AzSqlServerKeyVaultKey:ResourceGroupName','Get-AzSqlServerDnsAlias:ResourceGroupName','New-AzSqlServerDnsAlias:ResourceGroupName','Set-AzSqlServerDnsAlias:ResourceGroupName','Get-AzSqlServerDisasterRecoveryConfiguration:ResourceGroupName','Get-AzSqlServerDisasterRecoveryConfigurationActivity:ResourceGroupName','New-AzSqlServerDisasterRecoveryConfiguration:ResourceGroupName','Remove-AzSqlServerDisasterRecoveryConfiguration:ResourceGroupName','Set-AzSqlServerDisasterRecoveryConfiguration:ResourceGroupName','Get-AzSqlServerCommunicationLink:ResourceGroupName','New-AzSqlServerCommunicationLink:ResourceGroupName','Remove-AzSqlServerCommunicationLink:ResourceGroupName','Get-AzSqlServerActiveDirectoryAdministrator:ResourceGroupName','Remove-AzSqlServerActiveDirectoryAdministrator:ResourceGroupName','Set-AzSqlServerActiveDirectoryAdministrator:ResourceGroupName','Get-AzSqlDatabaseReplicationLink:ResourceGroupName','New-AzSqlDatabaseCopy:ResourceGroupName','New-AzSqlDatabaseSecondary:ResourceGroupName','Remove-AzSqlDatabaseSecondary:ResourceGroupName','Set-AzSqlDatabaseSecondary:ResourceGroupName','Get-AzSqlElasticPoolRecommendation:ResourceGroupName','Get-AzSqlDatabaseRecommendedAction:ResourceGroupName','Get-AzSqlElasticPoolRecommendedAction:ResourceGroupName','Get-AzSqlServerRecommendedAction:ResourceGroupName','Set-AzSqlDatabaseRecommendedActionState:ResourceGroupName','Set-AzSqlElasticPoolRecommendedActionState:ResourceGroupName','Set-AzSqlServerRecommendedActionState:ResourceGroupName','Get-AzSqlServerOutboundFirewallRule:ResourceGroupName','New-AzSqlServerOutboundFirewallRule:ResourceGroupName','Remove-AzSqlServerOutboundFirewallRule:ResourceGroupName','Get-AzSqlInstanceStartStopSchedule:ResourceGroupName','New-AzSqlInstanceStartStopSchedule:ResourceGroupName','Remove-AzSqlInstanceStartStopSchedule:ResourceGroupName','Invoke-AzSqlInstanceFailover:ResourceGroupName','Start-AzSqlInstance:ResourceGroupName','Stop-AzSqlInstance:ResourceGroupName','Get-AzSqlInstanceDatabaseLogReplay:ResourceGroupName','Get-AzSqlInstanceDatabaseCopyOperation:ResourceGroupName','Get-AzSqlInstanceDatabaseMoveOperation:ResourceGroupName','Get-AzSqlDeletedInstanceDatabaseBackup:ResourceGroupName','Get-AzSqlInstanceDatabaseBackupLongTermRetentionPolicy:ResourceGroupName','Set-AzSqlInstanceDatabaseBackupLongTermRetentionPolicy:ResourceGroupName','Get-AzSqlServerIpv6FirewallRule:ResourceGroupName','New-AzSqlServerIpv6FirewallRule:ResourceGroupName','Remove-AzSqlServerIpv6FirewallRule:ResourceGroupName','Set-AzSqlServerIpv6FirewallRule:ResourceGroupName','New-AzSqlInstancePool:ResourceGroupName','Get-AzSqlDatabaseInstanceFailoverGroup:ResourceGroupName','New-AzSqlDatabaseInstanceFailoverGroup:ResourceGroupName','Get-AzSqlDatabaseIndexRecommendation:ResourceGroupName','Start-AzSqlDatabaseExecuteIndexRecommendation:ResourceGroupName','Stop-AzSqlDatabaseExecuteIndexRecommendation:ResourceGroupName','New-AzSqlDatabaseExport:ResourceGroupName','New-AzSqlDatabaseImport:ResourceGroupName','Get-AzSqlServerFirewallRule:ResourceGroupName','New-AzSqlServerFirewallRule:ResourceGroupName','Remove-AzSqlServerFirewallRule:ResourceGroupName','Set-AzSqlServerFirewallRule:ResourceGroupName','Add-AzSqlDatabaseToFailoverGroup:ResourceGroupName','Get-AzSqlDatabaseFailoverGroup:ResourceGroupName','New-AzSqlDatabaseFailoverGroup:ResourceGroupName','Remove-AzSqlDatabaseFromFailoverGroup:ResourceGroupName','Remove-AzSqlDatabaseFailoverGroup:ResourceGroupName','Set-AzSqlDatabaseFailoverGroup:ResourceGroupName','Switch-AzSqlDatabaseFailoverGroup:ResourceGroupName','Invoke-AzSqlServerExternalGovernanceStatusRefresh:ResourceGroupName','Get-AzSqlElasticPool:ResourceGroupName','Get-AzSqlElasticPoolActivity:ResourceGroupName','Get-AzSqlElasticPoolDatabase:ResourceGroupName','Invoke-AzSqlElasticPoolFailover:ResourceGroupName','New-AzSqlElasticPool:ResourceGroupName','Remove-AzSqlElasticPool:ResourceGroupName','Set-AzSqlElasticPool:ResourceGroupName','Stop-AzSqlElasticPoolActivity:ResourceGroupName','Get-AzSqlDatabase:ResourceGroupName','Get-AzSqlDatabaseActivity:ResourceGroupName','Get-AzSqlDatabaseExpanded:ResourceGroupName','Invoke-AzSqlDatabaseFailover:ResourceGroupName','Invoke-AzSqlDatabaseTransparentDataEncryptionProtectorRevalidation:ResourceGroupName','Invoke-AzSqlDatabaseTransparentDataEncryptionProtectorRevert:ResourceGroupName','New-AzSqlDatabase:ResourceGroupName','Remove-AzSqlDatabase:ResourceGroupName','Set-AzSqlDatabase:ResourceGroupName','Stop-AzSqlDatabaseActivity:ResourceGroupName','Get-AzSqlDatabaseGeoBackup:ResourceGroupName','Get-AzSqlDeletedDatabaseBackup:ResourceGroupName','Get-AzSqlDatabaseBackupLongTermRetentionPolicy:ResourceGroupName','Get-AzSqlDatabaseGeoBackupPolicy:ResourceGroupName','Get-AzSqlDatabaseRestorePoint:ResourceGroupName','New-AzSqlDatabaseRestorePoint:ResourceGroupName','Remove-AzSqlDatabaseRestorePoint:ResourceGroupName','Restore-AzSqlDatabase:ResourceGroupName','Set-AzSqlDatabaseBackupLongTermRetentionPolicy:ResourceGroupName','Set-AzSqlDatabaseGeoBackupPolicy:ResourceGroupName','Resume-AzSqlDatabase:ResourceGroupName','Suspend-AzSqlDatabase:ResourceGroupName','Get-AzSqlSyncAgent:ResourceGroupName','Get-AzSqlSyncAgentLinkedDatabase:ResourceGroupName','Get-AzSqlSyncGroup:ResourceGroupName','Get-AzSqlSyncGroupLog:ResourceGroupName','Get-AzSqlSyncMember:ResourceGroupName','Get-AzSqlSyncSchema:ResourceGroupName','New-AzSqlSyncAgent:ResourceGroupName','New-AzSqlSyncAgentKey:ResourceGroupName','New-AzSqlSyncGroup:ResourceGroupName','New-AzSqlSyncMember:ResourceGroupName','Remove-AzSqlSyncAgent:ResourceGroupName','Remove-AzSqlSyncGroup:ResourceGroupName','Remove-AzSqlSyncMember:ResourceGroupName','Start-AzSqlSyncGroupSync:ResourceGroupName','Stop-AzSqlSyncGroupSync:ResourceGroupName','Update-AzSqlSyncGroup:ResourceGroupName','Update-AzSqlSyncMember:ResourceGroupName','Update-AzSqlSyncSchema:ResourceGroupName','Get-AzSqlDatabaseDataMaskingPolicy:ResourceGroupName','Get-AzSqlDatabaseDataMaskingRule:ResourceGroupName','New-AzSqlDatabaseDataMaskingRule:ResourceGroupName','Remove-AzSqlDatabaseDataMaskingRule:ResourceGroupName','Set-AzSqlDatabaseDataMaskingPolicy:ResourceGroupName','Set-AzSqlDatabaseDataMaskingRule:ResourceGroupName','Get-AzSqlDatabaseAdvisor:ResourceGroupName','Get-AzSqlElasticPoolAdvisor:ResourceGroupName','Get-AzSqlServerAdvisor:ResourceGroupName','Set-AzSqlDatabaseAdvisorAutoExecuteStatus:ResourceGroupName','Set-AzSqlElasticPoolAdvisorAutoExecuteStatus:ResourceGroupName','Set-AzSqlServerAdvisorAutoExecuteStatus:ResourceGroupName','Disable-AzSqlInstanceAdvancedDataSecurity:ResourceGroupName','Disable-AzSqlServerAdvancedDataSecurity:ResourceGroupName','Enable-AzSqlInstanceAdvancedDataSecurity:ResourceGroupName','Enable-AzSqlServerAdvancedDataSecurity:ResourceGroupName','Get-AzSqlInstanceAdvancedDataSecurityPolicy:ResourceGroupName','Get-AzSqlServerAdvancedDataSecurityPolicy:ResourceGroupName','Get-AzSqlDatabaseAdvancedThreatProtectionSetting:ResourceGroupName','Get-AzSqlInstanceDatabaseAdvancedThreatProtectionSetting:ResourceGroupName','Get-AzSqlInstanceAdvancedThreatProtectionSetting:ResourceGroupName','Get-AzSqlServerAdvancedThreatProtectionSetting:ResourceGroupName','Update-AzSqlDatabaseAdvancedThreatProtectionSetting:ResourceGroupName','Update-AzSqlInstanceDatabaseAdvancedThreatProtectionSetting:ResourceGroupName','Update-AzSqlInstanceAdvancedThreatProtectionSetting:ResourceGroupName','Update-AzSqlServerAdvancedThreatProtectionSetting:ResourceGroupName')

if ($Env:ACC_CLOUD -eq $null)
{
    $FilteredCommands | ForEach-Object {

        $existingDefault = $false
        foreach ($key in $global:PSDefaultParameterValues.Keys)
        {
            if ($_ -like "$key")
            {
                $existingDefault = $true
            }
        }

        if (!$existingDefault)
        {
            $global:PSDefaultParameterValues.Add($_,
                {
                    if ((Get-Command Get-AzContext -ErrorAction Ignore) -eq $null)
                    {
                        $context = Get-AzureRmContext
                    }
                    else
                    {
                        $context = Get-AzContext
                    }
                    if (($context -ne $null) -and $context.ExtendedProperties.ContainsKey("Default Resource Group")) {
                        $context.ExtendedProperties["Default Resource Group"]
                    }
                })
        }
    }
}



# SIG # Begin signature block
# MIInvgYJKoZIhvcNAQcCoIInrzCCJ6sCAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCAiDU0CffS13cvU
# 7E5cAqMuk85hqadLRcp3wWihWSAiWKCCDXYwggX0MIID3KADAgECAhMzAAADrzBA
# DkyjTQVBAAAAAAOvMA0GCSqGSIb3DQEBCwUAMH4xCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25p
# bmcgUENBIDIwMTEwHhcNMjMxMTE2MTkwOTAwWhcNMjQxMTE0MTkwOTAwWjB0MQsw
# CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9u
# ZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMR4wHAYDVQQDExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24wggEiMA0GCSqGSIb3DQEBAQUAA4IBDwAwggEKAoIB
# AQDOS8s1ra6f0YGtg0OhEaQa/t3Q+q1MEHhWJhqQVuO5amYXQpy8MDPNoJYk+FWA
# hePP5LxwcSge5aen+f5Q6WNPd6EDxGzotvVpNi5ve0H97S3F7C/axDfKxyNh21MG
# 0W8Sb0vxi/vorcLHOL9i+t2D6yvvDzLlEefUCbQV/zGCBjXGlYJcUj6RAzXyeNAN
# xSpKXAGd7Fh+ocGHPPphcD9LQTOJgG7Y7aYztHqBLJiQQ4eAgZNU4ac6+8LnEGAL
# go1ydC5BJEuJQjYKbNTy959HrKSu7LO3Ws0w8jw6pYdC1IMpdTkk2puTgY2PDNzB
# tLM4evG7FYer3WX+8t1UMYNTAgMBAAGjggFzMIIBbzAfBgNVHSUEGDAWBgorBgEE
# AYI3TAgBBggrBgEFBQcDAzAdBgNVHQ4EFgQURxxxNPIEPGSO8kqz+bgCAQWGXsEw
# RQYDVR0RBD4wPKQ6MDgxHjAcBgNVBAsTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEW
# MBQGA1UEBRMNMjMwMDEyKzUwMTgyNjAfBgNVHSMEGDAWgBRIbmTlUAXTgqoXNzci
# tW2oynUClTBUBgNVHR8ETTBLMEmgR6BFhkNodHRwOi8vd3d3Lm1pY3Jvc29mdC5j
# b20vcGtpb3BzL2NybC9NaWNDb2RTaWdQQ0EyMDExXzIwMTEtMDctMDguY3JsMGEG
# CCsGAQUFBwEBBFUwUzBRBggrBgEFBQcwAoZFaHR0cDovL3d3dy5taWNyb3NvZnQu
# Y29tL3BraW9wcy9jZXJ0cy9NaWNDb2RTaWdQQ0EyMDExXzIwMTEtMDctMDguY3J0
# MAwGA1UdEwEB/wQCMAAwDQYJKoZIhvcNAQELBQADggIBAISxFt/zR2frTFPB45Yd
# mhZpB2nNJoOoi+qlgcTlnO4QwlYN1w/vYwbDy/oFJolD5r6FMJd0RGcgEM8q9TgQ
# 2OC7gQEmhweVJ7yuKJlQBH7P7Pg5RiqgV3cSonJ+OM4kFHbP3gPLiyzssSQdRuPY
# 1mIWoGg9i7Y4ZC8ST7WhpSyc0pns2XsUe1XsIjaUcGu7zd7gg97eCUiLRdVklPmp
# XobH9CEAWakRUGNICYN2AgjhRTC4j3KJfqMkU04R6Toyh4/Toswm1uoDcGr5laYn
# TfcX3u5WnJqJLhuPe8Uj9kGAOcyo0O1mNwDa+LhFEzB6CB32+wfJMumfr6degvLT
# e8x55urQLeTjimBQgS49BSUkhFN7ois3cZyNpnrMca5AZaC7pLI72vuqSsSlLalG
# OcZmPHZGYJqZ0BacN274OZ80Q8B11iNokns9Od348bMb5Z4fihxaBWebl8kWEi2O
# PvQImOAeq3nt7UWJBzJYLAGEpfasaA3ZQgIcEXdD+uwo6ymMzDY6UamFOfYqYWXk
# ntxDGu7ngD2ugKUuccYKJJRiiz+LAUcj90BVcSHRLQop9N8zoALr/1sJuwPrVAtx
# HNEgSW+AKBqIxYWM4Ev32l6agSUAezLMbq5f3d8x9qzT031jMDT+sUAoCw0M5wVt
# CUQcqINPuYjbS1WgJyZIiEkBMIIHejCCBWKgAwIBAgIKYQ6Q0gAAAAAAAzANBgkq
# hkiG9w0BAQsFADCBiDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24x
# EDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
# bjEyMDAGA1UEAxMpTWljcm9zb2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9yaXR5
# IDIwMTEwHhcNMTEwNzA4MjA1OTA5WhcNMjYwNzA4MjEwOTA5WjB+MQswCQYDVQQG
# EwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwG
# A1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQg
# Q29kZSBTaWduaW5nIFBDQSAyMDExMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIIC
# CgKCAgEAq/D6chAcLq3YbqqCEE00uvK2WCGfQhsqa+laUKq4BjgaBEm6f8MMHt03
# a8YS2AvwOMKZBrDIOdUBFDFC04kNeWSHfpRgJGyvnkmc6Whe0t+bU7IKLMOv2akr
# rnoJr9eWWcpgGgXpZnboMlImEi/nqwhQz7NEt13YxC4Ddato88tt8zpcoRb0Rrrg
# OGSsbmQ1eKagYw8t00CT+OPeBw3VXHmlSSnnDb6gE3e+lD3v++MrWhAfTVYoonpy
# 4BI6t0le2O3tQ5GD2Xuye4Yb2T6xjF3oiU+EGvKhL1nkkDstrjNYxbc+/jLTswM9
# sbKvkjh+0p2ALPVOVpEhNSXDOW5kf1O6nA+tGSOEy/S6A4aN91/w0FK/jJSHvMAh
# dCVfGCi2zCcoOCWYOUo2z3yxkq4cI6epZuxhH2rhKEmdX4jiJV3TIUs+UsS1Vz8k
# A/DRelsv1SPjcF0PUUZ3s/gA4bysAoJf28AVs70b1FVL5zmhD+kjSbwYuER8ReTB
# w3J64HLnJN+/RpnF78IcV9uDjexNSTCnq47f7Fufr/zdsGbiwZeBe+3W7UvnSSmn
# Eyimp31ngOaKYnhfsi+E11ecXL93KCjx7W3DKI8sj0A3T8HhhUSJxAlMxdSlQy90
# lfdu+HggWCwTXWCVmj5PM4TasIgX3p5O9JawvEagbJjS4NaIjAsCAwEAAaOCAe0w
# ggHpMBAGCSsGAQQBgjcVAQQDAgEAMB0GA1UdDgQWBBRIbmTlUAXTgqoXNzcitW2o
# ynUClTAZBgkrBgEEAYI3FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYwDwYD
# VR0TAQH/BAUwAwEB/zAfBgNVHSMEGDAWgBRyLToCMZBDuRQFTuHqp8cx0SOJNDBa
# BgNVHR8EUzBRME+gTaBLhklodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2Ny
# bC9wcm9kdWN0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFfMDNfMjIuY3JsMF4GCCsG
# AQUFBwEBBFIwUDBOBggrBgEFBQcwAoZCaHR0cDovL3d3dy5taWNyb3NvZnQuY29t
# L3BraS9jZXJ0cy9NaWNSb29DZXJBdXQyMDExXzIwMTFfMDNfMjIuY3J0MIGfBgNV
# HSAEgZcwgZQwgZEGCSsGAQQBgjcuAzCBgzA/BggrBgEFBQcCARYzaHR0cDovL3d3
# dy5taWNyb3NvZnQuY29tL3BraW9wcy9kb2NzL3ByaW1hcnljcHMuaHRtMEAGCCsG
# AQUFBwICMDQeMiAdAEwAZQBnAGEAbABfAHAAbwBsAGkAYwB5AF8AcwB0AGEAdABl
# AG0AZQBuAHQALiAdMA0GCSqGSIb3DQEBCwUAA4ICAQBn8oalmOBUeRou09h0ZyKb
# C5YR4WOSmUKWfdJ5DJDBZV8uLD74w3LRbYP+vj/oCso7v0epo/Np22O/IjWll11l
# hJB9i0ZQVdgMknzSGksc8zxCi1LQsP1r4z4HLimb5j0bpdS1HXeUOeLpZMlEPXh6
# I/MTfaaQdION9MsmAkYqwooQu6SpBQyb7Wj6aC6VoCo/KmtYSWMfCWluWpiW5IP0
# wI/zRive/DvQvTXvbiWu5a8n7dDd8w6vmSiXmE0OPQvyCInWH8MyGOLwxS3OW560
# STkKxgrCxq2u5bLZ2xWIUUVYODJxJxp/sfQn+N4sOiBpmLJZiWhub6e3dMNABQam
# ASooPoI/E01mC8CzTfXhj38cbxV9Rad25UAqZaPDXVJihsMdYzaXht/a8/jyFqGa
# J+HNpZfQ7l1jQeNbB5yHPgZ3BtEGsXUfFL5hYbXw3MYbBL7fQccOKO7eZS/sl/ah
# XJbYANahRr1Z85elCUtIEJmAH9AAKcWxm6U/RXceNcbSoqKfenoi+kiVH6v7RyOA
# 9Z74v2u3S5fi63V4GuzqN5l5GEv/1rMjaHXmr/r8i+sLgOppO6/8MO0ETI7f33Vt
# Y5E90Z1WTk+/gFcioXgRMiF670EKsT/7qMykXcGhiJtXcVZOSEXAQsmbdlsKgEhr
# /Xmfwb1tbWrJUnMTDXpQzTGCGZ4wghmaAgEBMIGVMH4xCzAJBgNVBAYTAlVTMRMw
# EQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVN
# aWNyb3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNp
# Z25pbmcgUENBIDIwMTECEzMAAAOvMEAOTKNNBUEAAAAAA68wDQYJYIZIAWUDBAIB
# BQCgga4wGQYJKoZIhvcNAQkDMQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEO
# MAwGCisGAQQBgjcCARUwLwYJKoZIhvcNAQkEMSIEIBAQ5VBKFLKwsIsZTnIA0oAe
# uVlI3gonqCxyDZdxnrPPMEIGCisGAQQBgjcCAQwxNDAyoBSAEgBNAGkAYwByAG8A
# cwBvAGYAdKEagBhodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20wDQYJKoZIhvcNAQEB
# BQAEggEAcOD9fwekhxoju8NGUWul7xcVAdfiXkQk9HRKBTeVa14gBaoQI/j0Flow
# Ir5+I36CKCU9Cp0znuPsjUbU4DMW+7clhaaw62/NG5x2/N4Mscy9hRW5Ft6m+1f4
# B6vd04fnkaNZ0w5acq4/nwqlaRKzRhNXrpyxYrWCD4MHcipy9lemCfyHOTV4Lvbp
# 5jgDnGnLvJiE604f/NSbDLgBcYuwCqCQPBHM/hqvNB40+20IZIRMxK+hAcCPlse6
# araeut3XeSGpySj7YJB9DqiIC9JggK24L/44p0NZ2puRYXpNbogmWZ84ZuNaJhvj
# M1OOA4hSw65LTaDGUkzO3ogpzecsf6GCFygwghckBgorBgEEAYI3AwMBMYIXFDCC
# FxAGCSqGSIb3DQEHAqCCFwEwghb9AgEDMQ8wDQYJYIZIAWUDBAIBBQAwggFYBgsq
# hkiG9w0BCRABBKCCAUcEggFDMIIBPwIBAQYKKwYBBAGEWQoDATAxMA0GCWCGSAFl
# AwQCAQUABCC6mtxvhyOFVLuOsyJDhrqixjxbQiuyY08piYqh33uEhQIGZYLpKY4M
# GBIyMDIzMTIyNzA1NTU1MC4zMlowBIACAfSggdikgdUwgdIxCzAJBgNVBAYTAlVT
# MRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQK
# ExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xLTArBgNVBAsTJE1pY3Jvc29mdCBJcmVs
# YW5kIE9wZXJhdGlvbnMgTGltaXRlZDEmMCQGA1UECxMdVGhhbGVzIFRTUyBFU046
# OEQ0MS00QkY3LUIzQjcxJTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1lLVN0YW1wIFNl
# cnZpY2WgghF4MIIHJzCCBQ+gAwIBAgITMwAAAePfvZuaHGiDIgABAAAB4zANBgkq
# hkiG9w0BAQsFADB8MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQ
# MA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9u
# MSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1TdGFtcCBQQ0EgMjAxMDAeFw0yMzEw
# MTIxOTA3MjlaFw0yNTAxMTAxOTA3MjlaMIHSMQswCQYDVQQGEwJVUzETMBEGA1UE
# CBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9z
# b2Z0IENvcnBvcmF0aW9uMS0wKwYDVQQLEyRNaWNyb3NvZnQgSXJlbGFuZCBPcGVy
# YXRpb25zIExpbWl0ZWQxJjAkBgNVBAsTHVRoYWxlcyBUU1MgRVNOOjhENDEtNEJG
# Ny1CM0I3MSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2aWNlMIIC
# IjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAvqQNaB5Gn5/FIFQPo3/K4Qml
# eCDMF40bkoHwz0BshZ4SiQmA6CGUyDwmaqQ2wHhaXU0RdHtwvq+U8KxYYsyHKqax
# xC7fr/yHZvHpNTgzx1VkR3pXhT6X2Cm175UX3WQ4jfl86onp5AMzBIFDlz0SU8VS
# KNMDvNXtjk9FitLgUv2nj3hOJ0KkEQfk3oA7m7zA0D+Mo73hmR+OC7uwsXxJR2tz
# UZE0STYX3UvenFH7fYWy5BNmLyGq2sWkQ5HFvJKCJAE/dwft8+V43U3KeExF/pPt
# cLUvQ9HIrL0xnpMFau7Yd5aK+TEi57WctBv87+fSPZBV3jZl/QCtcH9WrniBDwki
# 9QfRxu/JYzw+iaEWLqrYXuF7jeOGvHK+fVeLWnAc5WxsfbpjEMpNbGXbSF9At3PP
# hFVOjxwVEx1ALGUqRKehw9ap9X/gfkA9I9eTSvwJz9wya9reDgS+6kXgSttI7RQ2
# cJG/tQPGVIaLCIaSafLneaq0Bns0t4+EW3B/GnoBMiiOXwleOvf5udBZQIMJ3k5q
# nnh8Z4ZhTwrE6iGbPrTgGBPXh7exFYAGlb6hdhILIVDdJlDf8s1NVvL0Q2y4SHZQ
# hApZTuW/tyGsGscIPDSMz5bA6NhRLtjEwCFpLI5qGlu50Au9FRelCEQsWg7q07H/
# rqHOqCNJM4Rjem7joEUCAwEAAaOCAUkwggFFMB0GA1UdDgQWBBSxrg1mvjUVt6Fn
# xj56nabZiJipAzAfBgNVHSMEGDAWgBSfpxVdAF5iXYP05dJlpxtTNRnpcjBfBgNV
# HR8EWDBWMFSgUqBQhk5odHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2Ny
# bC9NaWNyb3NvZnQlMjBUaW1lLVN0YW1wJTIwUENBJTIwMjAxMCgxKS5jcmwwbAYI
# KwYBBQUHAQEEYDBeMFwGCCsGAQUFBzAChlBodHRwOi8vd3d3Lm1pY3Jvc29mdC5j
# b20vcGtpb3BzL2NlcnRzL01pY3Jvc29mdCUyMFRpbWUtU3RhbXAlMjBQQ0ElMjAy
# MDEwKDEpLmNydDAMBgNVHRMBAf8EAjAAMBYGA1UdJQEB/wQMMAoGCCsGAQUFBwMI
# MA4GA1UdDwEB/wQEAwIHgDANBgkqhkiG9w0BAQsFAAOCAgEAt76bLqnU08wRbW3v
# RrxjaEbGPqyINK6UYCzhTGaR/PEwCJziPT4ZM9sfGTX3eZDQVE9r121tFtp7NXQY
# uQSxRZMYXa0/pawN2Xn+UPjBRDvoCsU56dwKkrmy8TSw7QXKGskdnEwsI5yW93q8
# Ag86RkBiKEEf9FdzHNuKWI4Kv//fDtESewu46n/u+VckCwbOYl6wE//QRGrGMq50
# 9a4EbP+p1GUm06Xme/01mTIuKDgPmHL2nYRzXNqi2IuIecn2aWwkRxQOFiPw+dic
# mOOwLG/7InNqjZpQeIhDMxsWr4zTxzy4ER/6zfthtlDtcAXHB7YRUkBTClaOa0nd
# vfNJZMyYVa6cWvZouTq9V5LS7UzIR8S/7RsOT43eOawLBsuQz0VoOLurYe1SffPq
# TsCcRNzbx0C8t/+KipStVhPAGttEfhdUUS9ohD6Lt6wNCJxZbV0IMD8nfE6gIQJX
# rzrXWOuJqN91WDyjRan4UKDkIBS2yWA4W6JhQuBzGerOSY/aLnxkRrSubgtnKYcH
# OwgxTTIya5WYCRjFt0QOLleqVki6k+mqYPr98uMPi5vRIQS206mDSenStr8w0J+/
# +1WEm3PnCCIQgpf6zhqRrAt9j7XrEMHrg2bQegaz8bLzbe6UibgbKtRyk1nGde8T
# o5kyMj9XUCBICDxT+F4xa5lNZVQwggdxMIIFWaADAgECAhMzAAAAFcXna54Cm0mZ
# AAAAAAAVMA0GCSqGSIb3DQEBCwUAMIGIMQswCQYDVQQGEwJVUzETMBEGA1UECBMK
# V2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0
# IENvcnBvcmF0aW9uMTIwMAYDVQQDEylNaWNyb3NvZnQgUm9vdCBDZXJ0aWZpY2F0
# ZSBBdXRob3JpdHkgMjAxMDAeFw0yMTA5MzAxODIyMjVaFw0zMDA5MzAxODMyMjVa
# MHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdS
# ZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMT
# HU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEwMIICIjANBgkqhkiG9w0BAQEF
# AAOCAg8AMIICCgKCAgEA5OGmTOe0ciELeaLL1yR5vQ7VgtP97pwHB9KpbE51yMo1
# V/YBf2xK4OK9uT4XYDP/XE/HZveVU3Fa4n5KWv64NmeFRiMMtY0Tz3cywBAY6GB9
# alKDRLemjkZrBxTzxXb1hlDcwUTIcVxRMTegCjhuje3XD9gmU3w5YQJ6xKr9cmmv
# Haus9ja+NSZk2pg7uhp7M62AW36MEBydUv626GIl3GoPz130/o5Tz9bshVZN7928
# jaTjkY+yOSxRnOlwaQ3KNi1wjjHINSi947SHJMPgyY9+tVSP3PoFVZhtaDuaRr3t
# pK56KTesy+uDRedGbsoy1cCGMFxPLOJiss254o2I5JasAUq7vnGpF1tnYN74kpEe
# HT39IM9zfUGaRnXNxF803RKJ1v2lIH1+/NmeRd+2ci/bfV+AutuqfjbsNkz2K26o
# ElHovwUDo9Fzpk03dJQcNIIP8BDyt0cY7afomXw/TNuvXsLz1dhzPUNOwTM5TI4C
# vEJoLhDqhFFG4tG9ahhaYQFzymeiXtcodgLiMxhy16cg8ML6EgrXY28MyTZki1ug
# poMhXV8wdJGUlNi5UPkLiWHzNgY1GIRH29wb0f2y1BzFa/ZcUlFdEtsluq9QBXps
# xREdcu+N+VLEhReTwDwV2xo3xwgVGD94q0W29R6HXtqPnhZyacaue7e3PmriLq0C
# AwEAAaOCAd0wggHZMBIGCSsGAQQBgjcVAQQFAgMBAAEwIwYJKwYBBAGCNxUCBBYE
# FCqnUv5kxJq+gpE8RjUpzxD/LwTuMB0GA1UdDgQWBBSfpxVdAF5iXYP05dJlpxtT
# NRnpcjBcBgNVHSAEVTBTMFEGDCsGAQQBgjdMg30BATBBMD8GCCsGAQUFBwIBFjNo
# dHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL0RvY3MvUmVwb3NpdG9yeS5o
# dG0wEwYDVR0lBAwwCgYIKwYBBQUHAwgwGQYJKwYBBAGCNxQCBAweCgBTAHUAYgBD
# AEEwCwYDVR0PBAQDAgGGMA8GA1UdEwEB/wQFMAMBAf8wHwYDVR0jBBgwFoAU1fZW
# y4/oolxiaNE9lJBb186aGMQwVgYDVR0fBE8wTTBLoEmgR4ZFaHR0cDovL2NybC5t
# aWNyb3NvZnQuY29tL3BraS9jcmwvcHJvZHVjdHMvTWljUm9vQ2VyQXV0XzIwMTAt
# MDYtMjMuY3JsMFoGCCsGAQUFBwEBBE4wTDBKBggrBgEFBQcwAoY+aHR0cDovL3d3
# dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0cy9NaWNSb29DZXJBdXRfMjAxMC0wNi0y
# My5jcnQwDQYJKoZIhvcNAQELBQADggIBAJ1VffwqreEsH2cBMSRb4Z5yS/ypb+pc
# FLY+TkdkeLEGk5c9MTO1OdfCcTY/2mRsfNB1OW27DzHkwo/7bNGhlBgi7ulmZzpT
# Td2YurYeeNg2LpypglYAA7AFvonoaeC6Ce5732pvvinLbtg/SHUB2RjebYIM9W0j
# VOR4U3UkV7ndn/OOPcbzaN9l9qRWqveVtihVJ9AkvUCgvxm2EhIRXT0n4ECWOKz3
# +SmJw7wXsFSFQrP8DJ6LGYnn8AtqgcKBGUIZUnWKNsIdw2FzLixre24/LAl4FOmR
# sqlb30mjdAy87JGA0j3mSj5mO0+7hvoyGtmW9I/2kQH2zsZ0/fZMcm8Qq3UwxTSw
# ethQ/gpY3UA8x1RtnWN0SCyxTkctwRQEcb9k+SS+c23Kjgm9swFXSVRk2XPXfx5b
# RAGOWhmRaw2fpCjcZxkoJLo4S5pu+yFUa2pFEUep8beuyOiJXk+d0tBMdrVXVAmx
# aQFEfnyhYWxz/gq77EFmPWn9y8FBSX5+k77L+DvktxW/tM4+pTFRhLy/AsGConsX
# HRWJjXD+57XQKBqJC4822rpM+Zv/Cuk0+CQ1ZyvgDbjmjJnW4SLq8CdCPSWU5nR0
# W2rRnj7tfqAxM328y+l7vzhwRNGQ8cirOoo6CGJ/2XBjU02N7oJtpQUQwXEGahC0
# HVUzWLOhcGbyoYIC1DCCAj0CAQEwggEAoYHYpIHVMIHSMQswCQYDVQQGEwJVUzET
# MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMV
# TWljcm9zb2Z0IENvcnBvcmF0aW9uMS0wKwYDVQQLEyRNaWNyb3NvZnQgSXJlbGFu
# ZCBPcGVyYXRpb25zIExpbWl0ZWQxJjAkBgNVBAsTHVRoYWxlcyBUU1MgRVNOOjhE
# NDEtNEJGNy1CM0I3MSUwIwYDVQQDExxNaWNyb3NvZnQgVGltZS1TdGFtcCBTZXJ2
# aWNloiMKAQEwBwYFKw4DAhoDFQA9iJe7w5FDiG8py4TsYrQI6DFaeqCBgzCBgKR+
# MHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdS
# ZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xJjAkBgNVBAMT
# HU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEwMA0GCSqGSIb3DQEBBQUAAgUA
# 6TX4xDAiGA8yMDIzMTIyNzA5MTM0MFoYDzIwMjMxMjI4MDkxMzQwWjB0MDoGCisG
# AQQBhFkKBAExLDAqMAoCBQDpNfjEAgEAMAcCAQACAgkLMAcCAQACAhDGMAoCBQDp
# N0pEAgEAMDYGCisGAQQBhFkKBAIxKDAmMAwGCisGAQQBhFkKAwKgCjAIAgEAAgMH
# oSChCjAIAgEAAgMBhqAwDQYJKoZIhvcNAQEFBQADgYEAsw6gYqpqfB0JznLhmTfi
# SVbKDFki73BAf2m9XJIXghpFyvZc8MfzFIg9/u7PgcMiTMC/naEiEyEbB+WZC8/T
# r4oLFCtkO6SiQRjAdXUINaSvjFgDgpAnzeB+slnRcPkA8IOHDXO1HpfvQLechdlM
# XS5AiGi/8jX0sZbAfW+6bE4xggQNMIIECQIBATCBkzB8MQswCQYDVQQGEwJVUzET
# MBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMV
# TWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGltZS1T
# dGFtcCBQQ0EgMjAxMAITMwAAAePfvZuaHGiDIgABAAAB4zANBglghkgBZQMEAgEF
# AKCCAUowGgYJKoZIhvcNAQkDMQ0GCyqGSIb3DQEJEAEEMC8GCSqGSIb3DQEJBDEi
# BCDMC4klyQaAqQ1lMVY4NPebAnHuT/r0ls8QmsJ+T6cuvDCB+gYLKoZIhvcNAQkQ
# Ai8xgeowgecwgeQwgb0EIDPUI6vlsP5k90SBCNa9wha4MlxBt2Crw12PTHIy5iYq
# MIGYMIGApH4wfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAO
# BgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEm
# MCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTACEzMAAAHj372b
# mhxogyIAAQAAAeMwIgQgXnsqMMUUYYaSJGENKWIaOe2HIZNmwBt9uGAALp1fi48w
# DQYJKoZIhvcNAQELBQAEggIACHqcnObRAkLwLY8kSLVWDsw418lzv92SsY1C7iuG
# IM0bppAg3dk/yHCEPtOK57PSLAsXqF41szwlaIDoDLV+KkmTWDSu8Q9KZ4Q8pX07
# OP/eUBZyGtaffEG6ThnMREjU+7CeIlAFA8ZlRLtgejTCjlnM+qhm6aX0snon9PfP
# +ZsxPeQsSHabUn20VQaO+yJ89mNtKSnuRBBthZ3IuIE/HPxdQvzviN2KBAgDMfB1
# gv75PbyaSgv/jGIOcBJyH3jbEuxsd8vaIxjIi4P+9Wj0TlzkdYglHuoaDn/fsp1a
# gfn579Ofzzr7q5ZEEj12xQTzH1LBmBNMi3KPyndvWuMZ8cGmB7z2xqk2dH9gHRsw
# C7rmBgzELj2YvyPR4N9xqL6Q8Gzo4qLuux20TPXb48eiipx51YQodfSwGNF3UWtB
# ZJ5BjrueN3gl9be6gxsKx4W9hBRt2XBvWortnBFGdcEwx/u02XaG8OaS7u1zkOqN
# 6zKs08tLfcqxt2Uzg03uDb+N8tf96S8QwOZdLmV8/UYrLEBmiBGtwHhrQxb0GmK7
# cUMptjbDOKP4B1iEaR8gcQOTCvw61oqCygzfHOvC8TdNQdfgu5LMsmaWxElSW5Mq
# 2KB5tQshg8vLgeQRzc8c116DoyT+MxuFGjdjq0QVinLt7GPeJ4IqZ1N5bzBjIWlO
# 77I=
# SIG # End signature block
